==> mongodb-ui-components-5.0.8.tgz: package/src/footer/sections.js <==
export const sections = [
  {
    title: 'Resources',
    maxWidth: '185',
    items: [
      ['/nosql-explained', 'NoSQL Database Explained'],
      ['/lp/white-paper/architecture-guide', 'MongoDB Architecture Guide'],
      ['/products/mongodb-enterprise-advanced', 'MongoDB Enterprise Advanced'],
      ['/cloud/atlas', 'MongoDB Atlas'],
      ['/cloud/stitch', 'MongoDB Stitch'],
      ['//engineering.mongodb.com/', 'MongoDB Engineering Blog', true],
      ['/cloud/atlas/refer', 'Referral Program']
    ]
  }, {
    title: 'Education & Support',
    maxWidth: '150',
    items: [
      ['//university.mongodb.com/courses/catalog', 'View Course Catalog'],
      ['//university.mongodb.com/exams', 'Certification'],
      ['//docs.mongodb.com/manual/', 'MongoDB Manual'],
      ['//docs.mongodb.com/manual/installation/', 'Installation'],
      ['/faq', 'FAQ']
    ]
  }, {
    title: 'Popular Topics',
    className: 'be-ix-link-block',
    maxWidth: '300',
    items: [
      [
        '/cloud/atlas/migrate',
        'Migrate to MongoDB Atlas'
      ], [
        '/blog/post/building-a-rest-api-with-mongodb-stitch',
        'Building a REST API with MongoDB Stitch'
      ], [
        '/post/ingesting-and-visualizing-api-data-with-stitch-and-charts',
        'Ingesting and Visualizing API Data with Stitch and Charts'
      ]
    ]
  }, {
    title: 'About',
    maxWidth: '100',
    items: [
      ['/company', 'MongoDB, Inc.'],
      ['/leadership', 'Leadership'],
      ['/pressroom', 'Press Room'],
      ['//investors.mongodb.com', 'Investors'],
      ['/careers', 'Careers'],
      ['/contact', 'Contact Us'],
      ['/legal/legal-notices', 'Legal Notices'],
      ['/security', 'Security Information'],
      ['/office-locations', 'Office Locations'],
      ['/community-code-of-conduct', 'Code of Conduct']
    ]
  }, {
    title: 'Follow Us',
    hasIcons: true,
    maxWidth: '120',
    items: [
      ['//facebook.com/mongodb', 'Facebook'],
      ['//github.com/mongodb', 'Github'],
      ['//youtube.com/user/mongodb', 'Youtube'],
      ['//twitter.com/mongodb', 'Twitter'],
      ['//www.linkedin.com/company/mongodbinc/', 'LinkedIn'],
      ['//slackpass.io/mongo-db', 'Slack'],
      ['//stackoverflow.com/tags/mongodb/info', 'StackOverflow']
    ]
  }
]

==> mongodb-ui-components-5.1.1.tgz: package/src/footer/sections.js <==
export const sections = [
  {
    title: 'Resources',
    maxWidth: '185',
    items: [
      ['/nosql-explained', 'NoSQL Database Explained'],
      ['/lp/white-paper/architecture-guide', 'MongoDB Architecture Guide'],
      ['/products/mongodb-enterprise-advanced', 'MongoDB Enterprise Advanced'],
      ['/cloud/atlas', 'MongoDB Atlas'],
      ['/cloud/stitch', 'MongoDB Stitch'],
      ['//engineering.mongodb.com/', 'MongoDB Engineering Blog', true]
    ]
  }, {
    title: 'Education & Support',
    maxWidth: '150',
    items: [
      ['//university.mongodb.com/courses/catalog', 'View Course Catalog'],
      ['//university.mongodb.com/exams', 'Certification'],
      ['//docs.mongodb.com/manual/', 'MongoDB Manual'],
      ['//docs.mongodb.com/manual/installation/', 'Installation'],
      ['/faq', 'FAQ']
    ]
  }, {
    title: 'Popular Topics',
    className: 'be-ix-link-block',
    maxWidth: '300',
    items: [
      [
        '/cloud/atlas/migrate',
        'Migrate to MongoDB Atlas'
      ], [
        '/blog/post/building-a-rest-api-with-mongodb-stitch',
        'Building a REST API with MongoDB Stitch'
      ], [
        '/post/ingesting-and-visualizing-api-data-with-stitch-and-charts',
        'Ingesting and Visualizing API Data with Stitch and Charts'
      ]
    ]
  }, {
    title: 'About',
    maxWidth: '100',
    items: [
      ['/company', 'MongoDB, Inc.'],
      ['/leadership', 'Leadership'],
      ['/pressroom', 'Press Room'],
      ['//investors.mongodb.com', 'Investors'],
      ['/careers', 'Careers'],
      ['/contact', 'Contact Us'],
      ['/legal/legal-notices', 'Legal Notices'],
      ['/security', 'Security Information'],
      ['/office-locations', 'Office Locations'],
      ['/community-code-of-conduct', 'Code of Conduct']
    ]
  }, {
    title: 'Follow Us',
    hasIcons: true,
    maxWidth: '120',
    items: [
      ['//facebook.com/mongodb', 'Facebook'],
      ['//github.com/mongodb', 'Github'],
      ['//youtube.com/user/mongodb', 'Youtube'],
      ['//twitter.com/mongodb', 'Twitter'],
      ['//www.linkedin.com/company/mongodbinc/', 'LinkedIn'],
      ['//slackpass.io/mongo-db', 'Slack'],
      ['//stackoverflow.com/tags/mongodb/info', 'StackOverflow']
    ]
  }
]
